.. suppy documentation master file, created by
   sphinx-quickstart on Tue Oct 15 15:16:07 2024.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

.. _api_documentation:

api documentation
===================

This is the documentation for suppy, a superiorization library for Python.
In general, the library has two main modules: feasibility and superiorization.
The feasibility and projection module contains algorithms and components for solving feasibility problems, while the superiorization module wraps the feasibility algorithms to create superiorization algorithms.


It is divided into the following modules:

.. toctree::
   :maxdepth: 1
   :caption: Modules:

   projections
   feasibility
   perturbations
   superiorization
   utils
